const postcss = require('postcss');

const shouldHandleFile = (configList = [], current) => configList.find((item) => {
  const { file } = item;
  if (typeof file === 'string') {
    return file === current;
  }
  return file.test(current);
});


const shouldHandleRule = ({ include, exclude, selector }) => {
  if (!include.length) {
    return exclude.includes(selector);
  }
  if (!exclude.length) {
    return !include.includes(selector);
  }
  return !include.includes(selector) && exclude.includes(selector);
};


module.exports = postcss.plugin('postcss-plugin-remove-selector', (opts = {}) => {
  const { list = [] } = opts;
  return function (root, result) {
    const fileName = result.opts.from;
    const found = shouldHandleFile(list, fileName);

    if (!found) {
      return;
    }
    const { exclude = [], include = [] } = found;
    console.log('[Postcss Plugin Remove Select] handling ', fileName);

    root.walkRules((rule) => {
      if (shouldHandleRule({
        exclude,
        include,
        selector: rule.selector,
      })) {
        rule.remove();
      }

      // rule.walkDecls((decl) => {
      //   console.log(`${decl.prop} = ${decl.value}`);
      // });
    });
  };
});
